@@ -7,14 +7,13 @@ CHINA_TZ = timezone("Asia/Shanghai")
 
 SQLITE_PATH_RR_PC = "/mnt/f/Stock/iwencai/"
 SQLITE_PATH_ALIYUN = "/mnt/disk1/sqlit_data/"
-PATH_ALIYUN = "/mnt/disk1/stock"
+PATH_ALIYUN = "/mnt/disk1/iwencai/"
 
 MAX_QUERY_SIZE: int = 6000
 WC_DATE_FORMATE: str = '%Y-%m-%d'
 MAX_QUERY_TIMES: int = 500
 
 
-
 HEADERS = {'Accept': 'text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,image/apng,*/*;q=0.8',
            'Accept-Encoding': 'gzip, deflate',
            'Accept-Language': 'zh-CN,zh;q=0.9',
@@ -139,4 +138,4 @@ class TRADE_TIMES():
     TRADE_TIME_AM = ['09:30:00','11:30:00']
     TRADE_TIME_PM = ["13:00:00","15:00:00"]
     TRADE_TIME_AM_pre = ['09:25:00','11:31:00']
-    TRADE_TIME_PM_pre = ["13:00:00","15:01:00"]
+    TRADE_TIME_PM_pre = ["13:00:00","15:01:00"]
\ No newline at end of file
